@@ -5,28 +5,34 @@ Copyright: 2021 rdbende
 """
 
 import tkinter as tk
-from tkinter import ttk
 from tkinter import font as tkfont
-
-from pygments import lex
-from pygments.lexers import *
-
-import json
-import os
-import warnings
+from tkinter import ttk
 
 from . import codebox
 
+
 class CodeBlock(codebox.BaseCodeBox):
-    def __init__(self, master=tk._default_root, language="python", highlighter="mariana", **kwargs):
+    def __init__(
+        self,
+        master=tk._default_root,
+        language="python",
+        highlighter="mariana",
+        autofocus=False,
+        **kwargs
+    ):
         kwargs.update({"state": "disabled"})
-        codebox.BaseCodeBox.__init__(self, master, language, highlighter, **kwargs)
+        kwargs.pop("xscrollcommand", None)
+        kwargs.pop("yscrollcommand", None)
+        codebox.BaseCodeBox.__init__(
+            self, master, language, highlighter, autofocus, **kwargs
+        )
 
     def disabler(func):
         def wrapper(self, *args, **kwargs):
             codebox.BaseCodeBox.config(self, state="normal")
             func(self, *args, **kwargs)
             codebox.BaseCodeBox.config(self, state="disabled")
+
         return wrapper
 
     @disabler
@@ -40,10 +46,9 @@ class CodeBlock(codebox.BaseCodeBox):
     @property
     def content(self):
         return self.get("1.0", "end")
-    
+
     @content.setter
     @disabler
     def content(self, new_content):
         self.delete("1.0", "end")
         self.insert("end", new_content)
-
